# Core Concepts

`measured` is a library for measurements and quantities.

[![PyPi](https://img.shields.io/pypi/v/measured)](https://pypi.org/project/measured)

::: measured
    options:
        show_root_toc_entry: true
